@@ -6,8 +6,8 @@ test_that("Add all samples to background", {
   expect_equal(nrow(o@data), 5800)
   expect_equal(nrow(o@coords), 5800)
   expect_equal(length(o@pa), 5800)
-  expect_equivalent(o@data[5401:5800, ], x@data[x@pa == 1, ])
-  expect_equivalent(o@coords[5401:5800, ], x@coords[x@pa == 1, ])
+  expect_equal(o@data[5401:5800, ], x@data[x@pa == 1, ], ignore_attr = TRUE)
+  expect_equal(o@coords[5401:5800, ], x@coords[x@pa == 1, ], ignore_attr = TRUE)
 })
 
 test_that("Add samples to background only if not duplicates", {
@@ -19,5 +19,5 @@ test_that("Add samples to background only if not duplicates", {
 })
 
 test_that("Error are raised", {
-  expect_error(addSamplesToBg(x@data), "The function accepts only SWD objects.")
+  expect_snapshot_error(addSamplesToBg(x@data))
 })
