@@ -2,8 +2,13 @@ p <- plotCor(SDMtune:::t, cor_th = .8, text_size = 4)
 
 test_that("The plot has the correct labels and text size", {
   expect_equal(p$plot_env$label, "Spearman's\ncoefficient")
-  expect_equal(p$labels$x, "Var2")
-  expect_equal(p$labels$y, "Var1")
+  labels <- if ("get_labs" %in% getNamespaceExports("ggplot2")) {
+    ggplot2::get_labs(p)
+  } else {
+    p$labels
+  }
+  expect_equal(labels$x, "Var2")
+  expect_equal(labels$y, "Var1")
   expect_equal(p$layers[[2]]$aes_params$size, 4)
 })
 
